~~# 本地文件上传~~

+ 接口：common/files/v2/upload
+ Method：POST
+ 数据格式：JSON
+ 限流信息：每小时1000次
+ 多语言环境：在接口请求头中添加Key为locale,Value值为语言环境,目前支持的语言有zh_CN(中文)、en_US(英文)、ja_JP(日文)、zh_TW(
  繁体),请选取其中一种
+ 接口说明：本地文件上传V2,支持指定文件下载时文件是否预览。
+ 其他补充信息：单个文件最大20M

### 请求参数

| 字段名称         | 字段类型    | 字段描述                                  | 
|--------------|---------|---------------------------------------| 
| file         | File    | 文件                                    |
| preview_flag | Boolean | 文件是否预览。 true-预览 false-不预览直接下载,默认false |

### 返回参数

| 字段名称            | 字段类型    | 字段描述       | 
|-----------------|---------|------------| 
| resCode         | Integer | 响应状态码（见附录） |
| resMsg          | String  | 返回信息描述     |
| data            | Array   | 上传成功结果数组   |
| data[].fileName | String  | 文件名        |
| data[].fileURL  | String  | 文件地址       |

## 示例

### 请求数据

```json
{
  "file": "test.txt",
  "preview_flag": true
}
```

### 返回数据

```json
{
  "resCode": 200000,
  "resMsg": "success",
  "data": {
    "attachment": {
      "attachmentURL": "xxx/out/ac1cc1c5-73a6-49c5-829c-f4274cfbc5c4.txt"
    }
  }
}
```

## 代码示例

```java
import okhttp3.MediaType;
import okhttp3.MultipartBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

public void uploadFile() throws IOException {
    OkHttpClient client = new OkHttpClient().newBuilder()
            .build();
    String path = "test.pdf";
    // 获取文件 MIME 类型
    String mimeType = Files.probeContentType(Paths.get(path));
    if (mimeType == null) {
        mimeType = "application/octet-stream"; // 设置默认 MIME 类型
    }
    RequestBody body = new MultipartBody.Builder().setType(MultipartBody.FORM)
            .addFormDataPart("file", path,
                    RequestBody.create(MediaType.parse(mimeType),
                            new File(path)))
            .addFormDataPart("preview_flag", "true")
            .build();
    Request request = new Request.Builder()
            .url("xxxx/common/files/v2/upload")
            .method("POST", body)
            .addHeader("access_token", "xxxx")
            .build();
    Response response = client.newCall(request).execute();
}
```